***************************************************************************************************************************************************
***************************************************************************************************************************************************

// master do-file
// 00_master.do

***************************************************************************************************************************************************
***************************************************************************************************************************************************

//Code was written using Stata 12
version 12


***************************************************************************************************************************************************
***************************************************************************************************************************************************

/*
README:

Follow these steps to replicate the results:
	1. Unzip "ReplicationFiles.zip"
	2. Register as a HRS data user (http://hrsonline.isr.umich.edu/index.php?p=reg)
	3. Download the following RAND HRS Files
		- The RAND HRS Data (Version L): rndhrs_l.dta 
			Save to folder "00_HRS/01_RAND"
		- The RAND HRS Family Data (Version B): rndfamk_b.dta 
			Save to folder "00_HRS/02_RAND_Family"
		- The RAND HRS Family Data (Version B): rndfamr_b.dta 
			Save to folder "00_HRS/02_RAND_Family"
	4. Open the do-file "00_master.do". You find this file in the folder "01_do-files"
	5. Customize your path for the global macro "workingDir"
	6. Run this do-file ("00_master.do") 
*/

***************************************************************************************************************************************************
***************************************************************************************************************************************************

//global macros for all paths

***********************************************
***********************************************

/*
--> specify your path !!!
*/

global workingDir 	"C:/YOUR_PATH/"

***********************************************
***********************************************

global HRS 			"${workingDir}/00_HRS"			// RAND HRS files; contains two subfolders
global dofiles 		"${workingDir}/01_do-files"		// do-files
global temp 		"${workingDir}/02_temp" 		// temporary files (should be deleted at the end of each do file)
global posted		"${workingDir}/03_posted"		// files considered to be ready for use in other do-files
global log 			"${workingDir}/04_logs" 		// log-files
global graphs 		"${workingDir}/05_graphs" 		// graphs

***************************************************************************************************************************************************
***************************************************************************************************************************************************

//Run all do-files to replicate the results presented in the paper

***********************************************
***********************************************

//create the baseline and the analytical sample using the RAND HRS files
do "${dofiles}/01_cr_BaselineAndAnalyticalSample.do"

***********************************************

//Description of the baseline sample for comparison
//with the analytical sample (see section "METHOD - sample" in the manuscript)
do "${dofiles}/02_an_Comparison_Baseline_vs_Analytical.do"


***********************************************

//Descriptive Results (Tables 1-4 in the manuscript)
do "${dofiles}/03_an_DescriptiveTables.do"


***********************************************

//Figure 1: "Change in Selected Characteristics Across
//the Transition to Parent Care"
do "${dofiles}/04_graph_PercentageChange.do"


***********************************************

//Table 5: "Fixed-Effects Logistic Regression Models 
//for the Transition to Parent Care" (+ robustness check)
do "${dofiles}/05_an_clogit"


***********************************************

//Figure 2: "Odds Ratios for the Transition to Parent Care"
do "${dofiles}/06_graph_OddsRatios.do"


***********************************************

//Decription of families with no variation in outcome measure
//(see section "Multivariate results" in the manuscript)
do "${dofiles}/07_an_DescribeDropouts.do"


***********************************************

//One-sided Wald tests for the inequality of coefficients
//(see section "Multivariate results" in the manuscript)
do "${dofiles}/08_an_WaldTests.do"


***************************************************************************************************************************************************
***************************************************************************************************************************************************
