*******************************************************************************************************************************
*******************************************************************************************************************************

//Regression Model
//03_an_clogit


*******************************************************************************************************************************
*******************************************************************************************************************************

//Open dataset

use  "${posted}/02_AnalyticalSample", clear


*******************************************************************************************************************************
*******************************************************************************************************************************

/*
Final Models include flags for missings
	* Model M1  --> same as M2 but without the mother-daughter effect
	* Model M2  --> full model including interaction

	* Model R1  --> Robustness check of Modell 2 with subsample with parents who 
				    did not receive help in the first two (or more) years of observation
*/

**********************************************************************************************
**********************************************************************************************

//Recode Missings

local a "kage khaskid knkid_within knkid knkid_c kgrandkid kcontact kdist keduyears keduyears_c"
local b "kwork kwork2 khlpiadl ktcany kdcare kfuturehelp kfirstborn klastborn klfins kdeed khmdeed kownrhm"


local vars `"`a' `b'"'

foreach x of local vars {
	replace `x' = 99 if `x'_miss == 1
	replace `x'_W2 = 99 if `x'_W2_miss == 1
	}

**********************************************************************************************	
**********************************************************************************************

*Model M1: Model without mother-daughter effect
qui clogit outcome ///
kage krrel ///
ib2.kdist kcouple ib0.khaskid ib0.kwork keduyears_c keduyears_c_miss ///
kfemale ib1.kcontact ib0.kfirstborn ///
ib0.ktcany ib0.kwill ib0.klfins ib0.khlpiadl ib0.kfuturehelp, or group(hhidpn)		

qui distinct hhidpn if e(sample)
estadd scalar Nfam = r(ndistinct)

estimates store M1

***********************************************

*Model M2: Full Model
qui clogit outcome ///
kage krrel ///
ib2.kdist kcouple ib0.khaskid ib0.kwork keduyears_c keduyears_c_miss ///
kfemale momdaughter ib1.kcontact ib0.kfirstborn ///
ib0.ktcany ib0.kwill ib0.klfins ib0.khlpiadl ib0.kfuturehelp, or group(hhidpn)	

qui distinct hhidpn if e(sample)
estadd scalar Nfam = r(ndistinct)

estimates store M2

***********************************************

//Table 5

estout M1 M2, ///
cells("b(fmt(%9.2f) star vacant(-))" se(par fmt(%9.2f))) ///
starlevels(+ 0.10 * 0.05 ** 0.01 *** 0.001)  legend ///
stats(r2_p N Nfam, fmt(%9.3f %9.0f %9.0f) ///
labels("Pseudo R-squared" "N (dyads)" "N (families)")) ///
varlabels(_cons Constant) varwidth(20) drop(*b.* 99* *miss) ///
collabels(none) 

qui distinct hhidpn if e(sample)

outreg2 [M1 M2] using "${log}/Clogit",  word excel replace cti(b) dec(2) ///
alpha(.001, .01, .05, .10) symbol(***, **, *, +) noobs drop(*b. 99* *miss) ///
adds("Pseudo R-squared", e(r2_p), "N (dyads)", e(N), "N (families)", e(Nfam))


outreg2 [M1 M2] using "${log}/Clogit_OR", word excel replace eform cti(Odds Ratio) dec(2) ///
alpha(.001, .01, .05, .10) symbol(***, **, *, +) noobs drop(*b. 99* *miss) ///
adds("Pseudo R-squared", e(r2_p), "N (dyads)", e(N), "N (families)", e(Nfam)) 


**********************************************************************************************
**********************************************************************************************

**********************************************************************************************
**********************************************************************************************

//Robustness check


qui clogit outcome ///
kage krrel ///
ib2.kdist kcouple ib0.khaskid ib0.kwork keduyears_c keduyears_c_miss ///
kfemale momdaughter ib1.kcontact ib0.kfirstborn ib0.ktcany ib0.kwill ///
ib0.klfins ib0.khlpiadl ib0.kfuturehelp if robustcheck == 1, or group(hhidpn)	

qui distinct hhidpn if e(sample)
estadd scalar Nfam = r(ndistinct)

estimates store R1

***********************************************


local rcheck "R1 - Two (or more) years without help"

estout M2 R1, ///
cells("b(fmt(%9.2f) star vacant(-))" se(par fmt(%9.2f))) ///
starlevels(+ 0.10 * 0.05 ** 0.01 *** 0.001)  legend ///
stats(r2_p N Nfam, fmt(%9.3f %9.0f %9.0f) ///
labels("Pseudo R-squared" "N (dyads)" "N (families)")) ///
varlabels(_cons Constant) varwidth(20) drop(*b.* 99* *miss) ///
postf(`"Model for robustness check: `rcheck2'"') collabels(none) 

**********************************************************************************************
**********************************************************************************************
