*******************************************************************************************************************************
*******************************************************************************************************************************

//Figure 2 - ODDS RATIOS FOR THE TRANSITION TO PARENT CARE
//05_graph_OddsRatios.do

*******************************************************************************************************************************
*******************************************************************************************************************************

//Open dataset

use  "${posted}/02_AnalyticalSample", clear

**********************************************************************************************
**********************************************************************************************

//Recode Missings

local a "kage khaskid knkid_within knkid knkid_c kgrandkid kcontact kdist keduyears keduyears_c"
local b "kwork kwork2 khlpiadl ktcany kdcare kfuturehelp kfirstborn klastborn klfins kdeed khmdeed kownrhm"


local vars `"`a' `b'"'

foreach x of local vars {
	replace `x' = 99 if `x'_miss == 1
	replace `x'_W2 = 99 if `x'_W2_miss == 1
	}

*******************************************************************************************************************************
*******************************************************************************************************************************

//Run model and convert estimations
//results to a dataset using "parmest"

clogit outcome ///
kage krrel ///
ib2.kdist kcouple ib0.khaskid ib0.kwork keduyears_c keduyears_c_miss ///
kfemale momdaughter ib1.kcontact ib0.kfirstborn ///
ib0.ktcany ib0.kwill ib0.klfins ib0.khlpiadl ib0.kfuturehelp, or group(hhidpn)	


parmest, norestore eform //user-written ado by Roger Newson

*******************************************************************************************************************************
*******************************************************************************************************************************

***********************************
//Data preparation for effect plot
***********************************


drop if inlist(parm, "kage", "krrel") //drop control variables
drop if z == . //drop empty "reference category"-entries
drop if regexm(parm, "^99") | regexm(parm, "miss"$) //drop missing indicators

***********************************************

*sort data for graph
*generate group variable with labels

gen aux =_n
gsort -aux

gen group = _n
drop aux

set obs `=_N + 8'
local i = `=_N - 8'
local z "1 2 5 8 10 13 15 17"

foreach x of local z {
	local ++i
	local t = `x' + .5
	replace group = `t' if _n == `i'
	}

set obs `=_N + 4'	

replace group = 10.7 in -1	
replace group = 10.8 in -2	
replace group = 17.7 in -3
replace group = 17.8 in -4

	
	
sort group	
replace group = _n

label define group ///
	29 " " /// Indicators of caregiving costs - line 2
	28 " " /// Indicators of caregiving costs - line 1
	27 " " /// Geographical distance (Ref.: > 10 miles)
	26 "Coresident" ///
	25 "<= 10 miles" ///
	24 " " /// Family demands
	23 "Married or lived with partner" ///
	22 "Has child(ren)" ///
	21 " " /// Employment (Ref.: Not employed)
	20 "Part-time" ///
	19 "Full-time" ///
	18 " " /// Years of education (bo extra line needed)
	17 " " /// Indicators of caregiving commitments - line 2
	16 " " /// Indicators of caregiving commitments - line 1
	15 " " /// Gender (Ref.: Son)
	14 "Daughter" ///
	13 "Mother-daughter-dyad" ///
	12 " " /// Contact frequency (Ref.: < weekly)
	11 "Weekly" ///
	10 "Daily" ///
	9  " " /// First-born (Ref.: later-born child)
	8  " " /// Reciprocity
	7  "Received financial transfer" ///
	6  "Included in will" ///
	5  "Beneficiary of life insurance" ///
	4  " " ///	Path dependency
	3  "Child helped with IADL" ///	
	2  " " /// Parental expectation	
	1  "Child named as expected caregiver" , replace	
	
label values group group	

gen minus2 = -2 //auxiliary variable for scatter plot
gen aux = .175


qui sum max95 if group == 6
scalar maximum = r(max) //save upper bound of kwill confidence interval 
replace max95 = 6 if group == 6 //top-code upper bound of kwill confidence interval 

	
*******************************************************************************************************************************
*******************************************************************************************************************************	

//Effect size plot (OR + CIs)

set scheme lean2 //user written scheme by Svend Juul

twoway ///
(rcap min95 max95 group, horizontal lcolor(gs7) lw(thin)) ///
(scatter group estimate, xline(1, lw(thin)) mcolor(black) msize(small)) ///
(scatter group aux, msymbol(i) mlabel(group) mlabc(black) mlabs(vsmall)) ///
(scatter group max95 if group == 6, msymbol(o) mcolor(white) msize(*1.7)) ///
(scatteri 6 6.1 6 8, c(l) lpattern(dash) lcolor(gs7) lw(thin) msym(none)), /// 
legend(off) ytitle("") yscale(range(0 29) off) ylabel(0(1)29,nogrid) ///
xscale(range(.33 6) log) xlabel(0.3 "Odds Ratio" 0.5 1 2 4 8, labs(vsmall) ///
noticks labgap(*2.5)) xtick(0.5 1 2 4 8) ///
text(27.4 .17 "{bf:Geographical distance (Ref.: > 10 miles)}", placement(se) just(left) size(vsmall)) ///
text(24.4 .17 "{bf:Family demands}", placement(se) just(left) size(vsmall)) /// 
text(21.4 .17 "{bf:Employment (Ref.: Not employed)}", placement(se) just(left) size(vsmall)) ///
text(18.45 .17 "{bf:Years of education}", placement(se) just(left) size(vsmall)) ///
text(15.4 .17 "{bf:Gender (Ref.: Son)}", placement(se) just(left) size(vsmall)) ///
text(12.4 .17 "{bf:Contact frequency (Ref.: < Weekly)}", placement(se) just(left) size(vsmall)) ///
text(9.45 .17 "{bf:First-born (Ref.: Later-born)}", placement(se) just(left) size(vsmall)) ///
text(8.4 .17 "{bf:Reciprocity}", placement(se) just(left) size(vsmall)) ///
text(4.4 .17 "{bf:Path dependency}", placement(se) just(left) size(vsmall)) /// 
text(2.4 .17 "{bf:Parental expectation}", placement(se) just(left) size(vsmall)) ///
text(16.8 .16 "{bf:Caregiving commitments}", placement(se) just(left) size(*.7)) ///
text(28.8 .16 "{bf:Caregiving costs}", placement(se) just(left) size(*.7)) ///
name(gr1,replace) 

graph save 		"${graphs}/OddsRatios", replace
graph export 	"${graphs}/OddsRatios.png", width(2000) replace
graph export 	"${graphs}/OddsRatios.emf", replace

*******************************************************************************************************************************
*******************************************************************************************************************************

