*******************************************************************************************************************************
*******************************************************************************************************************************

//Decription of 58 dropped families
//(no variation in outcome measure)
//07_an_DescribeDropouts.do


*******************************************************************************************************************************
*******************************************************************************************************************************

//Open dataset

use  "${posted}/02_AnalyticalSample", clear


*******************************************************************************************************************************
*******************************************************************************************************************************

//Recode Missings 

local a "kage khaskid knkid_within knkid knkid_c kgrandkid kcontact kdist keduyears keduyears_c"
local b "kwork kwork2 khlpiadl ktcany kdcare kfuturehelp kfirstborn klastborn klfins kdeed khmdeed kownrhm"


local vars `"`a' `b'"'

foreach x of local vars {
	replace `x' = 99 if `x'_miss == 1
	replace `x'_W2 = 99 if `x'_W2_miss == 1
	}

**********************************************************************************************	
**********************************************************************************************

//Final Model

***********************************************
***********************************************

*Model M2: Full Model
qui clogit outcome ///
kage krrel ///
ib2.kdist kcouple ib0.khaskid ib0.kwork keduyears_c keduyears_c_miss ///
kfemale momdaughter ib1.kcontact ib0.kfirstborn ///
ib0.ktcany ib0.kwill ib0.klfins ib0.khlpiadl ib0.kfuturehelp, or group(hhidpn)	

//Families not in the model due to kwill and missing variation in the outcome
gen aux = e(sample) != 1
bysort hhidpn (kidid): egen dropped = min(aux)
drop aux
distinct hhidpn if dropped == 1

//Families without variation in the outcome
bysort hhidpn (kidid): egen aux = total(outcome)
bysort hhidpn (kidid): replace aux = aux == _N
rename aux novariation
distinct hhidpn if novariation == 1

**********************************************************************************************
**********************************************************************************************

*******************************************************************************************************************************
*******************************************************************************************************************************

****************************
//Respondent (Parent) Level
****************************

*To obtain descriptives on respondent level, enter "if personlevel == 1 & dropped == 1"
*personlevel --> Dummy equals 1 only for one line per person

***********************************************

*Gender
sum rgender if personlevel == 1 & dropped == 1

*Age
sum ragey_W2 if personlevel == 1 & dropped == 1

*Partnership status
*fre rpartner rmarital if personlevel == 1 & dropped == 1
fre rpartner_W2 if personlevel == 1 & dropped == 1 //more interesting information

*Number of children
sum kidsindata if personlevel == 1 & dropped == 1
fre kidsindata if personlevel == 1 & dropped == 1


*Education: categorical
fre reduc if personlevel == 1 & dropped == 1

*Race
fre rrace if personlevel == 1 & dropped == 1

*Difficulties with IADLs
sum riadlza* if personlevel == 1 & dropped == 1

*Difficulties with ADLs
sum radla* if personlevel == 1 & dropped == 1


*******************************************************************************************************************************
*******************************************************************************************************************************


******************************
//Characteristics of children
******************************

*Gender
fre kfemale if dropped == 1

*Birth order
fre kfirstborn if kfirstborn_miss != 1 & dropped == 1

*Relation to respondent
fre krrel if dropped == 1

*Years of education
sum keduyears if keduyears_miss != 1 & dropped == 1
*fre keduyears_miss if dropped == 1

*Age
sum kage if kage_miss != 1 & dropped == 1
sum kage_W2 if kage_W2_miss != 1 & dropped == 1
*fre kage*miss if dropped == 1

*Partnership status
fre kcouple  if dropped == 1
fre kcouple_W2 if dropped == 1

*Child has own children
fre khaskid if khaskid_miss != 1 & dropped == 1
fre khaskid_W2 if khaskid_W2_miss != 1 & dropped == 1
*fre khaskid*miss if dropped == 1


*Employment status
fre kwork if kwork_miss != 1 & dropped == 1
*fre kwork_miss if dropped == 1

fre kwork_W2 if kwork_W2_miss != 1 & dropped == 1
*fre kwork_W2_miss if dropped == 1


*******************************************************************************************************************************
*******************************************************************************************************************************

***************
//Dyadic Level
***************

//Dyadic outcome measure
fre outcome if dropped == 1 

**********

*Distance W1
fre kdist if kdist_miss != 1 & dropped == 1 

*Distance W2
fre kdist_W2 if kdist_W2_miss != 1 & dropped == 1


*Contact frequency W1
fre kcontact if kcontact_miss != 1 & dropped == 1


*Contact frequency W2
fre kcontact_W2 if kcontact_W2_miss != 1 & dropped == 1


**********

//Reciprocity indicators

*Child received financial transfer W1
fre ktcany if ktcany_miss != 1 & dropped == 1


*Child received financial transfer W2
fre ktcany_W2 if ktcany_W2_miss != 1 & dropped == 1


*Child received financial transfer W2 and helps
*fre ktcany_W2 if ktcany_W2_miss != 1 & dropped == 1 & outcome == 1

*Child included in will W1
fre kwill if kwill_miss != 1 & dropped == 1


*Child included in will W2
fre kwill_W2 if kwill_W2_miss != 1 & dropped == 1


*Child included in will W2 and helps
*fre kwill_W2 if kwill_W2_miss != 1 & dropped == 1 & outcome == 1

*Child is beneficiary of life insurance W1
fre klfins if klfins_miss != 1 & dropped == 1


*Child is beneficiary of life insurance W2
fre klfins_W2 if klfins_W2_miss != 1 & dropped == 1


*Child is beneficiary of life insurance W2 and helps
*fre klfins_W2 if klfins_W2_miss != 1 & dropped == 1 & outcome == 1


**********

//Path dependency

*Child helps with IADLs W1
fre khlpiadl if khlpiadl_miss != 1 & dropped == 1


*Child helps with IADLs W2
fre khlpiadl_W2 if khlpiadl_W2_miss != 1 & dropped == 1


/*
*Child helps with IADLs and ADLs W2
fre khlpiadl_W2 if khlpiadl_W2_miss != 1 & dropped == 1 & outcome == 1
*/

*Outcome conditional on prior help with IADLs
fre outcome if khlpiadl == 1 & dropped == 1 
fre outcome if khlpiadl == 0 & dropped == 1


**********

//Parental expectation

*Child named as expected caregiver
fre kfuturehelp if kfuturehelp_miss != 1 & dropped == 1


*******************************************************************************************************************************
*******************************************************************************************************************************





