*******************************************************************************************************************************
*******************************************************************************************************************************

//Testing "Hierarchy" of explaining factors
//using one-sided Wald tests for the inequality of coefficients
//08_an_WaldTests.do


*******************************************************************************************************************************
*******************************************************************************************************************************

//Open dataset

use  "${posted}/02_AnalyticalSample", clear


*******************************************************************************************************************************
*******************************************************************************************************************************

//Recode Missings 

local a "kage khaskid knkid_within knkid knkid_c kgrandkid kcontact kdist keduyears keduyears_c"
local b "kwork kwork2 khlpiadl ktcany kdcare kfuturehelp kfirstborn klastborn klfins kdeed khmdeed kownrhm"


local vars `"`a' `b'"'

foreach x of local vars {
	replace `x' = 99 if `x'_miss == 1
	replace `x'_W2 = 99 if `x'_W2_miss == 1
	}

**********************************************************************************************	
**********************************************************************************************

//Final Model

***********************************************
***********************************************

*Model M2: Full Model
qui clogit outcome ///
kage krrel ///
ib2.kdist kcouple ib0.khaskid ib0.kwork keduyears_c keduyears_c_miss ///
kfemale momdaughter ib1.kcontact ib0.kfirstborn ///
ib0.ktcany ib0.kwill ib0.klfins ib0.khlpiadl ib0.kfuturehelp, or group(hhidpn)	


**********************************************************************************************
**********************************************************************************************

//Run one-sided Wald tests for the inequality of coefficients

qui {
log using "${log}/WaldTests", replace text
noisily display as text _newline "**********************************"
noisily display as error _newline "Testing if coresidence-effect is bigger than..."

local z "1.kdist kcouple 1.khaskid 1.kwork 2.kwork keduyears_c"

foreach x of local z {
	test 0.kdist = `x'
	local sign_ag = sign(_b[0.kdist]-_b[`x'])
	
	gen aux = normal(`sign_ag'*sqrt(r(chi2)))

	gen aux2 = ".001***" if aux <= .001
	replace aux2 = ".01**" 	if inrange(aux,.0011,.01)
	replace aux2 = ".05*" 	if inrange(aux,.011,.05)
	replace aux2 = ".10+" 	if inrange(aux,.051,.1)
	replace aux2 = "n.s."	if inrange(aux,.11,1)
	levelsof aux2
	
	noisily display as text _newline "***"
	noisily display as result "Variable: `x'"
	noisily display as result  "H_0: 0.kdist >= `x' - p-value = " `r(levels)'
	noisily display as text"***"
	drop aux aux2
	}

noisily display as text _newline "**********************************"
log close
	}

**********************************************************************************************
**********************************************************************************************	

qui {
log using "${log}/WaldTests", append text
noisily display as text _newline "**********************************"
noisily display as error _newline "Testing if Living within 10 miles-effect is bigger than..."

local z "kcouple 1.khaskid 1.kwork 2.kwork keduyears_c"

foreach x of local z {
	test 1.kdist = `x'
	local sign_ag = sign(_b[1.kdist]-_b[`x'])
	
	gen aux = normal(`sign_ag'*sqrt(r(chi2)))

	gen aux2 = ".001***" if aux <= .001
	replace aux2 = ".01**" 	if inrange(aux,.0011,.01)
	replace aux2 = ".05*" 	if inrange(aux,.011,.05)
	replace aux2 = ".10+" 	if inrange(aux,.051,.1)
	replace aux2 = "n.s."	if inrange(aux,.11,1)
	levelsof aux2
	
	noisily display as text _newline "***"
	noisily display as result "Variable: `x'"
	noisily display as result  "H_0: 1.kdist >= `x' - p-value = " `r(levels)'
	noisily display as text"***"
	drop aux aux2
	}

noisily display as text _newline "**********************************"
log close
	}

**********************************************************************************************
**********************************************************************************************
	
qui {
log using "${log}/WaldTests", append text
noisily display as text _newline "**********************************"
noisily display as error _newline "Testing if kcouple-effect is bigger than..."

local z "0.kdist 1.kdist 1.khaskid 1.kwork 2.kwork keduyears_c"

foreach x of local z {
	test kcouple = `x'
	local sign_ag = sign(_b[kcouple]-_b[`x'])
	
	gen aux = normal(`sign_ag'*sqrt(r(chi2)))

	gen aux2 = ".001***" if aux <= .001
	replace aux2 = ".01**" 	if inrange(aux,.0011,.01)
	replace aux2 = ".05*" 	if inrange(aux,.011,.05)
	replace aux2 = ".10+" 	if inrange(aux,.051,.1)
	replace aux2 = "n.s."	if inrange(aux,.11,1)
	levelsof aux2
	
	noisily display as text _newline "***"
	noisily display as result "Variable: `x'"
	noisily display as result  "H_0: kcouple >= `x' - p-value = " `r(levels)'
	noisily display as text"***"
	drop aux aux2
	}

noisily display as text _newline "**********************************"
log close
	}
	
**********************************************************************************************
**********************************************************************************************
